@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -235,6 +235,26 @@ class MigrationServiceAsyncClient:
         ml.googleapis.com that can be migrated to Vertex AI's
         given location.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            async def sample_search_migratable_resources():
+                # Create a client
+                client = aiplatform_v1beta1.MigrationServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.SearchMigratableResourcesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.search_migratable_resources(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.SearchMigratableResourcesRequest, dict]):
                 The request object. Request message for
@@ -296,12 +316,20 @@ class MigrationServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.SearchMigratableResourcesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -323,6 +351,35 @@ class MigrationServiceAsyncClient:
         automl.googleapis.com, and datalabeling.googleapis.com
         to Vertex AI.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            async def sample_batch_migrate_resources():
+                # Create a client
+                client = aiplatform_v1beta1.MigrationServiceAsyncClient()
+
+                # Initialize request argument(s)
+                migrate_resource_requests = aiplatform_v1beta1.MigrateResourceRequest()
+                migrate_resource_requests.migrate_ml_engine_model_version_config.endpoint = "endpoint_value"
+                migrate_resource_requests.migrate_ml_engine_model_version_config.model_version = "model_version_value"
+                migrate_resource_requests.migrate_ml_engine_model_version_config.model_display_name = "model_display_name_value"
+
+                request = aiplatform_v1beta1.BatchMigrateResourcesRequest(
+                    parent="parent_value",
+                    migrate_resource_requests=migrate_resource_requests,
+                )
+
+                # Make the request
+                operation = client.batch_migrate_resources(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.BatchMigrateResourcesRequest, dict]):
                 The request object. Request message for
@@ -395,7 +452,12 @@ class MigrationServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
